==> dojo-1.10.6.tgz: package/cldr/nls/mk/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "сега",
	"field-weekday": "Ден во неделата",
	"field-wed-relative+0": "оваа среда",
	"dateFormatItem-GyMMMEd": "E, dd MMM y 'г'. G",
	"dateFormatItem-MMMEd": "E, dd MMM",
	"field-wed-relative+1": "следната среда",
	"field-tue-relative+-1": "минатиот вторник",
	"dateFormat-long": "dd MMMM y 'г'. G",
	"field-fri-relative+-1": "минатиот петок",
	"field-wed-relative+-1": "минатата среда",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE, dd MMMM y 'г'. G",
	"dateFormatItem-yyyyMEd": "E, dd.M.y G",
	"field-thu-relative+-1": "минатиот четврток",
	"dateFormatItem-Md": "dd.M",
	"field-era": "Ера",
	"field-year": "година",
	"dateFormatItem-yyyyMMMM": "MMMM y 'г'. G",
	"field-hour": "Час",
	"field-sat-relative+0": "оваа сабота",
	"field-sat-relative+1": "следната сабота",
	"field-day-relative+0": "Денес",
	"field-day-relative+1": "утре",
	"field-thu-relative+0": "овој четврток",
	"dateFormatItem-GyMMMd": "dd MMM y 'г'. G",
	"field-day-relative+2": "задутре",
	"field-thu-relative+1": "следниот четврток",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y 'г'. G",
	"dateFormatItem-yyyyMMMEd": "E, dd MMM y 'г'. G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y 'г'. G",
	"dateFormatItem-yyyyMMMd": "dd MMM y 'г'. G",
	"dateFormatItem-MMMMd": "dd MMMM",
	"field-sun-relative+0": "оваа недела",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "следната недела",
	"field-minute": "Минута",
	"field-dayperiod": "претпладне/попладне",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "вчера",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "завчера",
	"dateFormatItem-MMMd": "dd MMM",
	"dateFormatItem-MEd": "E, dd.M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "овој петок",
	"field-fri-relative+1": "следниот петок",
	"field-day": "ден",
	"field-zone": "зона",
	"dateFormatItem-y": "y 'г'. G",
	"field-year-relative+-1": "минатата година",
	"field-month-relative+-1": "минатиот месец",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-yyyyMd": "dd.M.y G",
	"field-month": "Месец",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "овој вторник",
	"field-tue-relative+1": "следниот вторник",
	"dateFormatItem-MMMMEd": "E, dd MMMM",
	"field-mon-relative+0": "овој понеделник",
	"field-mon-relative+1": "следниот понеделник",
	"dateFormat-short": "dd.M.y GGGGG",
	"field-second": "Секунда",
	"field-sat-relative+-1": "минатата сабота",
	"field-sun-relative+-1": "минатата недела",
	"field-month-relative+0": "овој месец",
	"field-month-relative+1": "следниот месец",
	"dateFormatItem-Ed": "d E",
	"field-week": "Недела",
	"dateFormat-medium": "dd.M.y G",
	"field-year-relative+0": "оваа година",
	"field-week-relative+-1": "минатата седмица",
	"dateFormatItem-yyyyM": "M.y G",
	"field-year-relative+1": "следната година",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y 'г'. G",
	"field-mon-relative+-1": "минатиот понеделник",
	"dateFormatItem-yyyy": "y 'г'. G",
	"field-week-relative+0": "оваа седмица",
	"field-week-relative+1": "следната седмица"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/mk/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "сега",
	"field-weekday": "Ден во неделата",
	"field-wed-relative+0": "оваа среда",
	"dateFormatItem-GyMMMEd": "E, dd MMM y 'г'. G",
	"dateFormatItem-MMMEd": "E, dd MMM",
	"field-wed-relative+1": "следната среда",
	"field-tue-relative+-1": "минатиот вторник",
	"dateFormat-long": "dd MMMM y 'г'. G",
	"field-fri-relative+-1": "минатиот петок",
	"field-wed-relative+-1": "минатата среда",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE, dd MMMM y 'г'. G",
	"dateFormatItem-yyyyMEd": "E, dd.M.y G",
	"field-thu-relative+-1": "минатиот четврток",
	"dateFormatItem-Md": "dd.M",
	"field-era": "Ера",
	"field-year": "година",
	"dateFormatItem-yyyyMMMM": "MMMM y 'г'. G",
	"field-hour": "Час",
	"field-sat-relative+0": "оваа сабота",
	"field-sat-relative+1": "следната сабота",
	"field-day-relative+0": "денес",
	"field-day-relative+1": "утре",
	"field-thu-relative+0": "овој четврток",
	"dateFormatItem-GyMMMd": "dd MMM y 'г'. G",
	"field-day-relative+2": "задутре",
	"field-thu-relative+1": "следниот четврток",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y 'г'. G",
	"dateFormatItem-yyyyMMMEd": "E, dd MMM y 'г'. G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y 'г'. G",
	"dateFormatItem-yyyyMMMd": "dd MMM y 'г'. G",
	"dateFormatItem-MMMMd": "dd MMMM",
	"field-sun-relative+0": "оваа недела",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "следната недела",
	"field-minute": "Минута",
	"field-dayperiod": "претпладне/попладне",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "вчера",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "завчера",
	"dateFormatItem-MMMd": "dd MMM",
	"dateFormatItem-MEd": "E, dd.M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "овој петок",
	"field-fri-relative+1": "следниот петок",
	"field-day": "ден",
	"field-zone": "зона",
	"dateFormatItem-y": "y 'г'. G",
	"field-year-relative+-1": "минатата година",
	"field-month-relative+-1": "минатиот месец",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-yyyyMd": "dd.M.y G",
	"field-month": "Месец",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "овој вторник",
	"field-tue-relative+1": "следниот вторник",
	"dateFormatItem-MMMMEd": "E, dd MMMM",
	"field-mon-relative+0": "овој понеделник",
	"field-mon-relative+1": "следниот понеделник",
	"dateFormat-short": "dd.M.y GGGGG",
	"field-second": "Секунда",
	"field-sat-relative+-1": "минатата сабота",
	"field-sun-relative+-1": "минатата недела",
	"field-month-relative+0": "овој месец",
	"field-month-relative+1": "следниот месец",
	"dateFormatItem-Ed": "d E",
	"field-week": "Недела",
	"dateFormat-medium": "dd.M.y G",
	"field-year-relative+0": "оваа година",
	"field-week-relative+-1": "минатата седмица",
	"dateFormatItem-yyyyM": "M.y G",
	"field-year-relative+1": "следната година",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y 'г'. G",
	"field-mon-relative+-1": "минатиот понеделник",
	"dateFormatItem-yyyy": "y 'г'. G",
	"field-week-relative+0": "оваа седмица",
	"field-week-relative+1": "следната седмица"
}
//end v1.x content
);
